import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/minwoopak/89107ac877ff2cb1741dfe08d91591d5/raw/cssNamedColors.csv';

const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;

const pieArc = arc().innerRadius(0).outerRadius(width);

const App = () => {
  const [data, setData] = useState(null);
  /*
  useEffect hook is needed whenever we do a side_effect(network request like fetching data).
  It lets you perform that side_effect only once.
  */
  useEffect(() => csv(csvUrl).then(setData)
    , []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  //// Utilizing d3.pie()
  return (
    <svg width={width} height={height}>
      <g transform={`translate( ${centerX}, ${centerY} )`}>
        {pie().value(1)(data)
          .map((d) => (
            <path
              fill={d.data['RGB hex value']}
              d={pieArc(d)}
            />
          ))}
      </g>
    </svg>
  );

  //// Manually creating arcs using d3.path()
  // return (
  //   <svg width={width} height={height}>
  //     <g transform={`translate( ${centerX}, ${centerY} )`}>
  //       {data.map((d, i) => (
  //         <path
  //           fill={d['RGB hex value']}
  //           d={pieArc({
  //             startAngle: (i / data.length) * (2 * Math.PI),
  //             endAngle:
  //               ((i + 1) / data.length) * (2 * Math.PI),
  //           })}
  //         />
  //       ))}
  //     </g>
  //   </svg>
  // );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
